# IMD Cookie Cutter
A tool for removing atoms in IMD config files, just like a cookie cutter in higher dimensions.

## Features
* Multiprocessed (**not implemented yet**)
* Without external dependencies
* Optimized for IMD \*.chkpt files
* Works in 2D and 3D (theoretically unlimited dimensions supported)
* Flexible slicing setup for your atom configuration by simply overriding a class
* Possibility to modify the atom data (coordinates, velocity, type, etc.) individually

## Installation
Install it by simply using pip:
```
python3 -m pip install [--user] imd-cookie-cutter
```
